@@ -1,20 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2005-2009 Osmo Salomaa
+# Copyright (C) 2005 Osmo Salomaa
 #
-# This file is part of Gaupol.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
-# Gaupol is free software: you can redistribute it and/or modify it under the
-# terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
 #
-# Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# Gaupol. If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
 Reading, writing and manipulating text-based subtitle files.
@@ -59,20 +58,10 @@ accessing the subtitles directly (via :attr:`aeidon.Project.subtitles`).
 :var CONFIG_HOME_DIR: Path to the user's local configuration directory
 :var DATA_DIR: Path to the global data directory
 :var DATA_HOME_DIR: Path to the user's local data directory
-:var DEBUG: ``True`` to perform additional run-time checks
-
-   `DEBUG` is used in many cases at import time and should thus not be set
-   directly, but rather by setting a non-blank value, e.g. "1", to either of
-   environment variables ``AEIDON_DEBUG`` or ``GAUPOL_DEBUG``.
-
 :var LOCALE_DIR: Path to the global locale directory
 :var RE_ANY_TAG: Regular expression for markup tags of any format
 :var RUNNING_SPHINX: ``True`` if generating API documentation with sphinx
 
-   `RUNNING_SPHINX` allows one to conditially do some funky things to ensure
-   that autogenerated API documentation is correct, while also avoiding that
-   funk during normal use of aeidon or gaupol.
-
 :var align_methods: Enumerations for subtitle align methods
 :var documents: Enumerations for document types
 :var formats: Enumerations for subtitle file format types
@@ -83,19 +72,14 @@ accessing the subtitles directly (via :attr:`aeidon.Project.subtitles`).
 :var registers: Enumerations for action action reversion register types
 """
 
-import os
 import re
 import sys
 
-__version__ = "0.24.3"
+__version__ = "0.26"
 
 RUNNING_SPHINX = (sys.argv[0].endswith("autogen.py") or
                   sys.argv[0].endswith("sphinx-build"))
 
-DEBUG = ((bool(os.environ.get("AEIDON_DEBUG", "")) or
-          bool(os.environ.get("GAUPOL_DEBUG", "")))
-         and not RUNNING_SPHINX)
-
 RE_ANY_TAG = re.compile(r"(^[/\\_]+|<.*?>|\{.*?\})")
 
 from aeidon.paths import *
@@ -104,7 +88,6 @@ from aeidon import deco
 from aeidon import i18n
 from aeidon import util
 from aeidon import temp
-from aeidon.contractual import *
 from aeidon.delegate import *
 from aeidon.singleton import *
 from aeidon.mutables import *
