@@ -1,24 +1,24 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2006-2009,2011-2012 Osmo Salomaa
+# Copyright (C) 2006 Osmo Salomaa
 #
-# This file is part of Gaupol.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
-# Gaupol is free software: you can redistribute it and/or modify it under the
-# terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
 #
-# Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# Gaupol. If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Miscellaneous functions."""
 
 import aeidon
+import collections
 import contextlib
 import inspect
 import locale
@@ -26,8 +26,8 @@ import os
 import random
 import re
 import shutil
-import subprocess
 import stat
+import subprocess
 import sys
 import urllib.parse
 
@@ -37,11 +37,7 @@ def affirm(value):
     if not value:
         raise aeidon.AffirmationError
 
-def atomic_open_require(path, mode="w", *args, **kwargs):
-    assert "w" in mode
-
 @contextlib.contextmanager
-@aeidon.deco.contractual
 def atomic_open(path, mode="w", *args, **kwargs):
     """
     A context manager for atomically writing a file.
@@ -67,13 +63,13 @@ def atomic_open(path, mode="w", *args, **kwargs):
             # If the file exists, use the same permissions.
             # Note that all other file metadata, including
             # owner and group, is not preserved.
-            with open(temp_path, "w") as fobj: pass
+            with open(temp_path, "w") as f: pass
             st = os.stat(path)
             os.chmod(temp_path, stat.S_IMODE(st.st_mode))
-        with open(temp_path, mode, *args, **kwargs) as fobj:
-            yield fobj
-            fobj.flush()
-            os.fsync(fobj.fileno())
+        with open(temp_path, mode, *args, **kwargs) as f:
+            yield f
+            f.flush()
+            os.fsync(f.fileno())
         try:
             if hasattr(os, "replace"):
                 # os.replace was added in Python 3.3.
@@ -97,10 +93,8 @@ def atomic_open(path, mode="w", *args, **kwargs):
                     os.remove(path)
             shutil.move(temp_path, path)
     finally:
-        try:
+        with silent(Exception):
             os.remove(temp_path)
-        except Exception:
-            pass
 
 @aeidon.deco.once
 def chardet_available():
@@ -111,29 +105,18 @@ def chardet_available():
     except Exception:
         return False
 
-def compare_versions_require(x, y):
-    re_version = re.compile(r"^(\d+\.)+\d+$")
-    assert re_version.match(x) is not None
-    assert re_version.match(y) is not None
-
-@aeidon.deco.contractual
 def compare_versions(x, y):
     """
     Compare version strings `x` and `y`.
 
-    Used version number formats are ``MAJOR.MINOR``, ``MAJOR.MINOR.PATCH`` and
-    ``MAJOR.MINOR.PATCH.DATE/REVISION``, where all items are integers.
+    Used version number formats are ``MAJOR.MINOR``, ``MAJOR.MINOR.PATCH``
+    and ``MAJOR.MINOR.PATCH.DATE/REVISION``, where all items are integers.
     Return 1 if `x` newer, 0 if equal or -1 if `y` newer.
     """
     compare = lambda a, b: (a > b) - (a < b)
     return compare(list(map(int, x.split("."))),
                    list(map(int, y.split("."))))
 
-def connect_require(observer, observable, signal, *args):
-    if observer is not observable:
-        assert hasattr(observer, observable)
-
-@aeidon.deco.contractual
 def connect(observer, observable, signal, *args):
     """
     Connect `observable`'s `signal` to `observer`'s callback method.
@@ -152,44 +135,6 @@ def connect(observer, observable, signal, *args):
         observable = getattr(observer, observable)
     return observable.connect(signal, method, *args)
 
-def copy_dict_ensure(src, value):
-    assert src == value
-    assert src is not value
-
-@aeidon.deco.contractual
-def copy_dict(src):
-    """Copy `src` dictionary recursively and return copy."""
-    dst = src.copy()
-    for key, value in src.items():
-        if isinstance(value, dict):
-            dst[key] = copy_dict(value)
-        if isinstance(value, list):
-            dst[key] = copy_list(value)
-        if isinstance(value, set):
-            dst[key] = set(value)
-    return dst
-
-def copy_list_ensure(src, value):
-    assert src == value
-    assert src is not value
-
-@aeidon.deco.contractual
-def copy_list(src):
-    """Copy `src` list recursively and return copy."""
-    dst = list(src)
-    for i, value in enumerate(src):
-        if isinstance(value, dict):
-            dst[i] = copy_dict(value)
-        if isinstance(value, list):
-            dst[i] = copy_list(value)
-        if isinstance(value, set):
-            dst[i] = set(value)
-    return dst
-
-def detect_format_require(path, encoding):
-    assert aeidon.encodings.is_valid_code(encoding)
-
-@aeidon.deco.contractual
 def detect_format(path, encoding):
     """
     Detect and return format of subtitle file at `path`.
@@ -200,8 +145,8 @@ def detect_format(path, encoding):
     Return an :attr:`aeidon.formats` enumeration item.
     """
     re_ids = [(x, re.compile(x.identifier)) for x in aeidon.formats]
-    with open(path, "r", encoding=encoding) as fobj:
-        for line in fobj:
+    with open(path, "r", encoding=encoding) as f:
+        for line in f:
             for format, re_id in re_ids:
                 if re_id.search(line) is not None:
                     return format
@@ -211,15 +156,25 @@ def detect_format(path, encoding):
 def detect_newlines(path):
     """Detect and return the newline type of file at `path` or ``None``."""
     try:
-        fobj = open(path, "r")
-        fobj.read()
-        chars = fobj.newlines
+        f = open(path, "r", newline="")
+        f.read()
+        chars = f.newlines
     except Exception:
         return None
-    if chars is None: return None
+    if chars is None:
+        return None
+    if isinstance(chars, str):
+        return aeidon.newlines.find_item("value", chars)
     if isinstance(chars, tuple):
-        chars = chars[0]
-    return aeidon.newlines.find_item("value", chars)
+        if len(chars) == 1:
+            return aeidon.newlines.find_item("value", chars[0])
+        # This is not actually correct. If both CR and LF are detected,
+        # it could mean a mixture of Mac and Unix newlines on separate
+        # lines or one Windows newline in a mostly something else file.
+        # We could count the frequencies, but it's probably not worth
+        # the effort.
+        return aeidon.newlines.WINDOWS
+    return None
 
 @aeidon.deco.once
 def enchant_available():
@@ -254,11 +209,6 @@ def flatten(lst):
             flat_lst.append(item)
     return flat_lst
 
-def get_chardet_version_ensure(value):
-    if value is not None:
-        assert isinstance(value, str)
-
-@aeidon.deco.contractual
 def get_chardet_version():
     """Return :mod:`chardet` version number as string or ``None``."""
     try:
@@ -267,11 +217,7 @@ def get_chardet_version():
     except Exception:
         return None
 
-def get_default_encoding_ensure(value):
-    assert aeidon.encodings.is_valid_code(value)
-
 @aeidon.deco.once
-@aeidon.deco.contractual
 def get_default_encoding(fallback="utf_8"):
     """Return the locale encoding or `fallback`."""
     encoding = locale.getpreferredencoding()
@@ -286,11 +232,6 @@ def get_default_newline():
     """Return system default newline as :attr:`aeidon.newlines` item."""
     return aeidon.newlines.find_item("value", os.linesep)
 
-def get_enchant_version_ensure(value):
-    if value is not None:
-        assert isinstance(value, str)
-
-@aeidon.deco.contractual
 def get_enchant_version():
     """Return :mod:`enchant` version number as string or ``None``."""
     try:
@@ -302,19 +243,10 @@ def get_enchant_version():
 def get_encoding_alias(encoding):
     """Return proper Python alias for `encoding`."""
     from encodings.aliases import aliases
-    if encoding in aliases:
+    with silent(LookupError):
         return aliases[encoding]
     return encoding
 
-def get_ranges_require(lst):
-    for item in lst:
-        assert isinstance(item, int)
-
-def get_ranges_ensure(value, lst):
-    for item in value:
-        assert item == list(range(item[0], item[-1] + 1))
-
-@aeidon.deco.contractual
 def get_ranges(lst):
     """
     Return a list of ranges in list of integers.
@@ -323,33 +255,15 @@ def get_ranges(lst):
     [[1, 2, 3], [5, 6, 7], [9], [11, 12]]
     """
     if not lst: return []
-    lst = get_sorted_unique(lst)
+    lst = sorted(get_unique(lst))
     ranges = [[lst.pop(0)]]
     for item in lst:
         if item == ranges[-1][-1] + 1:
             ranges[-1].append(item)
-        else: ranges.append([item])
+        else:
+            ranges.append([item])
     return ranges
 
-def get_sorted_unique_ensure(value, lst):
-    for item in value:
-        assert value.count(item) == 1
-    assert sorted(value) == value
-
-@aeidon.deco.contractual
-def get_sorted_unique(lst):
-    """
-    Return sorted `lst` with duplicates removed.
-
-    >>> aeidon.util.get_sorted_unique([3, 2, 1, 2, 4, 4])
-    [1, 2, 3, 4]
-    """
-    lst = sorted(lst)
-    for i in reversed(range(1, len(lst))):
-        if lst[i] == lst[i - 1]:
-            lst.pop(i)
-    return lst
-
 @aeidon.deco.memoize(100)
 def get_template_header(format):
     """
@@ -358,51 +272,23 @@ def get_template_header(format):
     Raise :exc:`IOError` if reading global header file fails.
     Raise :exc:`UnicodeError` if decoding global header file fails.
     """
-    header = None
     directory = os.path.join(aeidon.DATA_HOME_DIR, "headers")
     path = os.path.join(directory, format.name.lower())
-    if os.path.isfile(path):
-        try: header = read(path, None).rstrip()
-        except IOError:
-            print_read_io(sys.exc_info(), path)
-        except UnicodeError:
-            print_read_unicode(sys.exc_info(),
-                               path,
-                               get_default_encoding())
-
-    if header is None:
-        directory = os.path.join(aeidon.DATA_DIR, "headers")
-        path = os.path.join(directory, format.name.lower())
-        header = read(path, "ascii").rstrip()
+    with silent(Exception):
+        header = read(path, encoding=None, quiet=True).rstrip()
+        return normalize_newlines(header)
+    directory = os.path.join(aeidon.DATA_DIR, "headers")
+    path = os.path.join(directory, format.name.lower())
+    header = read(path, "ascii").rstrip()
     return normalize_newlines(header)
 
-def get_unique_ensure(value, lst, keep_last=False):
-    for item in value:
-        assert value.count(item) == 1
-
-@aeidon.deco.contractual
 def get_unique(lst, keep_last=False):
     """
-    Return `lst` with duplicates removed.
-
-    Keep the last duplicate if `keep_last` is ``True``, else keep first.
-
-    >>> aeidon.util.get_unique([3, 2, 1, 2, 4, 4])
-    [3, 2, 1, 4]
-    >>> aeidon.util.get_unique([3, 2, 1, 2, 4, 4], keep_last=True)
-    [3, 1, 2, 4]
-    """
-    lst = lst[:]
+    Return `lst` with duplicates removed."""
     if keep_last:
-        lst.reverse()
-    for i in reversed(range(len(lst))):
-        for j in range(0, i):
-            if lst[j] == lst[i]:
-                lst.pop(i)
-                break
-    if keep_last:
-        lst.reverse()
-    return lst
+        return list(reversed(get_unique(list(reversed(lst)))))
+    # http://stackoverflow.com/a/7961425
+    return list(collections.OrderedDict.fromkeys(lst))
 
 def install_module(name, obj):
     """
@@ -414,38 +300,30 @@ def install_module(name, obj):
     """
     aeidon.__dict__[name] = inspect.getmodule(obj)
 
-def is_command(command):
-    """Return ``True`` if `command` exists as a file in ``$PATH``."""
-    dirs = os.environ.get("PATH", "").split(os.pathsep)
-    paths = [os.path.join(x, command) for x in dirs]
-    return any(map(os.path.isfile, paths))
-
 def last(iterator):
     """Return the last value from `iterator` or ``None``."""
     value = None
     for value in iterator: pass
     return value
 
-def makedirs_ensure(value, directory):
-    assert os.path.isdir(directory)
-
-@aeidon.deco.contractual
 def makedirs(directory):
     """
     Recursively make `directory` if it does not exist.
 
     Raise :exc:`OSError` if unsuccessful.
     """
-    if not os.path.isdir(directory):
+    if os.path.isdir(directory): return
+    try:
         os.makedirs(directory)
+    except OSError as error:
+        print("Failed to create directory '{}': {}"
+              .format(directory, str(error)),
+              file=sys.stderr)
+
+        raise # OSError
 
 def normalize_newlines(text):
-    """
-    Convert all newlines in `text` to Unix newlines.
-
-    >>> aeidon.util.normalize_newlines("one\\r\\ntwo")
-    'one\\ntwo'
-    """
+    """Convert all newlines in `text` to "\\n"."""
     re_newline_char = re.compile(r"\r\n?")
     return re_newline_char.sub("\n", text)
 
@@ -468,12 +346,6 @@ def print_read_unicode(exc_info, path, encoding):
           .format(path, encoding),
           file=sys.stderr)
 
-def print_remove_os(exc_info, path):
-    """Print :exc:`OSError` message to standard error."""
-    print("Failed to remove file '{}': {}"
-          .format(path, exc_info[1].args[1]),
-          file=sys.stderr)
-
 def print_write_io(exc_info, path):
     """Print :exc:`IOError` message to standard error."""
     print("Failed to write file '{}': {}"
@@ -487,14 +359,7 @@ def print_write_unicode(exc_info, path, encoding):
           .format(path, encoding),
           file=sys.stderr)
 
-def read_require(path, encoding=None, fallback="utf_8"):
-    if encoding is not None:
-        assert aeidon.encodings.is_valid_code(encoding)
-    if fallback is not None:
-        assert aeidon.encodings.is_valid_code(fallback)
-
-@aeidon.deco.contractual
-def read(path, encoding=None, fallback="utf_8"):
+def read(path, encoding=None, fallback="utf_8", quiet=False):
     """
     Read file at `path` and return text.
 
@@ -504,21 +369,20 @@ def read(path, encoding=None, fallback="utf_8"):
     """
     encoding = encoding or get_default_encoding()
     try:
-        with open(path, "r", encoding=encoding) as fobj:
-            return fobj.read().strip()
+        with open(path, "r", encoding=encoding) as f:
+            return f.read().strip()
+    except IOError:
+        if not quiet:
+            print_read_io(sys.exc_info(), path)
+        raise # IOError
     except UnicodeError:
         if not fallback in (encoding, None, ""):
-            return read(path, fallback, None)
+            return read(path, fallback, None, quiet)
+        if not quiet:
+            print_read_unicode(sys.exc_info(), path, encoding)
         raise # UnicodeError
 
-def readlines_require(path, encoding=None, fallback="utf_8"):
-    if encoding is not None:
-        assert aeidon.encodings.is_valid_code(encoding)
-    if fallback is not None:
-        assert aeidon.encodings.is_valid_code(fallback)
-
-@aeidon.deco.contractual
-def readlines(path, encoding=None, fallback="utf_8"):
+def readlines(path, encoding=None, fallback="utf_8", quiet=False):
     """
     Read file at `path` and return lines.
 
@@ -526,7 +390,7 @@ def readlines(path, encoding=None, fallback="utf_8"):
     Raise :exc:`IOError` if reading fails.
     Raise :exc:`UnicodeError` if decoding fails.
     """
-    text = read(path, encoding, fallback)
+    text = read(path, encoding, fallback, quiet)
     text = normalize_newlines(text)
     return text.split("\n")
 
@@ -546,6 +410,14 @@ def shell_quote(path):
         path = path.replace('"', '\\"')
     return '"{}"'.format(path)
 
+@contextlib.contextmanager
+def silent(*exceptions):
+    """Try to execute body, ignoring `exceptions`."""
+    try:
+        yield
+    except exceptions:
+        pass
+
 def start_process(command, **kwargs):
     """
     Start `command` as a new background subprocess.
@@ -555,33 +427,22 @@ def start_process(command, **kwargs):
     Return :class:`subprocess.Popen` instance.
     """
     # Use no environment on Windows due to a subprocess bug.
-    # https://bugzilla.gnome.org/show_bug.cgi?id=605805
+    # http://bugzilla.gnome.org/show_bug.cgi?id=605805
+    env = (os.environ.copy() if sys.platform != "win32" else None)
     try:
         return subprocess.Popen(command,
                                 shell=(sys.platform != "win32"),
                                 cwd=os.getcwd(),
-                                env=(os.environ.copy()
-                                     if sys.platform != "win32"
-                                     else None),
-
+                                env=env,
                                 universal_newlines=True,
                                 **kwargs)
 
     except OSError as error:
-        raise aeidon.ProcessError(error.args[1])
-
-def title_to_lower_case_ensure(value, title_name):
-    assert value.islower()
+        raise aeidon.ProcessError(str(error.args))
 
 @aeidon.deco.memoize(100)
-@aeidon.deco.contractual
 def title_to_lower_case(title_name):
-    """
-    Convert title case name to lower case with underscores.
-
-    >>> aeidon.util.title_to_lower_case('TitleCase')
-    'title_case'
-    """
+    """Convert title case name to lower case with underscores."""
     lower_name = ""
     for char in title_name:
         if char.isupper() and lower_name:
@@ -599,17 +460,7 @@ def uri_to_path(uri):
         return path.replace("/", "\\")
     return urllib.parse.urlsplit(uri)[2]
 
-def write_require(path, text, encoding=None, fallback="utf_8"):
-    if encoding is not None:
-        assert aeidon.encodings.is_valid_code(encoding)
-    if fallback is not None:
-        assert aeidon.encodings.is_valid_code(fallback)
-
-def write_ensure(value, path, text, encoding=None, fallback="utf_8"):
-    assert os.path.isfile(path)
-
-@aeidon.deco.contractual
-def write(path, text, encoding=None, fallback="utf_8"):
+def write(path, text, encoding=None, fallback="utf_8", quiet=False):
     """
     Write `text` to file at `path`.
 
@@ -619,24 +470,20 @@ def write(path, text, encoding=None, fallback="utf_8"):
     """
     encoding = encoding or get_default_encoding()
     try:
-        with open(path, "w", encoding=encoding) as fobj:
-            return fobj.write(text)
+        with open(path, "w", encoding=encoding) as f:
+            return f.write(text)
+    except IOError:
+        if not quiet:
+            print_write_io(sys.exc_info(), path)
+        raise # IOError
     except UnicodeError:
         if not fallback in (encoding, None, ""):
-            return write(path, text, fallback, None)
+            return write(path, text, fallback, None, quiet)
+        if not quiet:
+            print_write_unicode(sys.exc_info(), path, encoding)
         raise # UnicodeError
 
-def writelines_require(path, lines, encoding=None, fallback="utf_8"):
-    if encoding is not None:
-        assert aeidon.encodings.is_valid_code(encoding)
-    if fallback is not None:
-        assert aeidon.encodings.is_valid_code(fallback)
-
-def writelines_ensure(value, path, lines, encoding=None, fallback="utf_8"):
-    assert os.path.isfile(path)
-
-@aeidon.deco.contractual
-def writelines(path, lines, encoding=None, fallback="utf_8"):
+def writelines(path, lines, encoding=None, fallback="utf_8", quiet=False):
     """
     Write `lines` of text to file at `path`.
 
@@ -644,5 +491,5 @@ def writelines(path, lines, encoding=None, fallback="utf_8"):
     Raise :exc:`IOError` if writing fails.
     Raise :exc:`UnicodeError` if encoding fails.
     """
-    text = os.linesep.join(lines) + os.linesep
-    return write(path, text, encoding, fallback)
+    text = "\n".join(lines) + "\n"
+    return write(path, text, encoding, fallback, quiet)
