@@ -1,35 +1,33 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2005-2010 Osmo Salomaa
+# Copyright (C) 2005 Osmo Salomaa
 #
-# This file is part of Gaupol.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
-# Gaupol is free software: you can redistribute it and/or modify it under the
-# terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
 #
-# Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# Gaupol. If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
 GTK+ user interface for the Gaupol subtitle editor.
 
 :var COMBO_SEPARATOR: String used as a separator for :class:`Gtk.ComboBox`
 
-   :attr:`COMBO_SEPARATOR` can be inserted into a combo box's model, and
-   :func:`gaupol.util.separate_combo` will recognize it.
+   :attr:`COMBO_SEPARATOR` can be inserted into a combo box's model,
+   and :func:`gaupol.util.separate_combo` will recognize it.
 
 :var BUG_REPORT_URL: Web page where to submit new bug reports
 :var EXTENSIONS_URL: Web page listing third party extensions
 :var HOMEPAGE_URL: Web page of the Gaupol project
 :var PREVIEW_HELP_URL: Documentation on the preview function
 :var REGEX_HELP_URL: Documentation on regular expressions
-:var SPEECH_RECOGNITION_HELP_URL: Documentation on speech recognition
 :var WIKI_URL: Wiki documentation
 
 :var fields: Enumerations for subtitle field types
@@ -45,7 +43,7 @@ GTK+ user interface for the Gaupol subtitle editor.
 :var conf: Instance of :class:`gaupol.ConfigurationStore` used
 """
 
-__version__ = "0.24.3"
+__version__ = "0.26"
 COMBO_SEPARATOR = "<separator/>"
 
 import aeidon
@@ -88,7 +86,6 @@ from gaupol.attrdict import *
 from gaupol.config import *
 conf = ConfigurationStore()
 from gaupol import ruler
-from gaupol.meta import *
 from gaupol.entries import *
 from gaupol.renderers import *
 from gaupol.floatlabel import *
@@ -107,7 +104,6 @@ from gaupol.dialogs.debug import *
 from gaupol.dialogs.duration_adjust import *
 from gaupol.dialogs.encoding import *
 from gaupol.dialogs.framerate_convert import *
-from gaupol.dialogs.header import *
 from gaupol.dialogs.insert import *
 from gaupol.dialogs.language import *
 from gaupol.dialogs.message import *
@@ -115,7 +111,6 @@ from gaupol.dialogs.multi_close import *
 from gaupol.dialogs.multi_save import *
 from gaupol.dialogs.preferences import *
 from gaupol.dialogs.preview_error import *
-from gaupol.dialogs.speech_recognition import *
 from gaupol.dialogs.search import *
 from gaupol.dialogs.position_shift import *
 from gaupol.dialogs.spell_check import *
