@@ -2,23 +2,23 @@
 
 # Copyright (C) 2010 Osmo Salomaa
 #
-# This file is part of Gaupol.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
-# Gaupol is free software: you can redistribute it and/or modify it under the
-# terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
 #
-# Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# Gaupol. If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Reading, writing and storing configurations."""
 
 import aeidon
+import copy
 import gaupol
 import json
 import os
@@ -34,7 +34,7 @@ config_defaults = {
         "position": [0, 0],
         "show_main_toolbar": True,
         "size": [700, 433],
-        "toolbar_style": gaupol.toolbar_styles.DEFAULT,
+        "toolbar_style": gaupol.toolbar_styles.ICONS,
         },
     "capitalization": {
         "country": "",
@@ -63,6 +63,7 @@ config_defaults = {
         "use_maximum": False,
         },
     "general": {
+        "dark_theme": False,
         "version": None,
         },
     "editor": {
@@ -124,7 +125,6 @@ config_defaults = {
         "country": "",
         "language": "",
         "length_unit": gaupol.length_units.EM,
-        "max_deviation": 0.16,
         "max_length": 28,
         "max_lines": 3,
         "script": "Latn",
@@ -161,15 +161,6 @@ config_defaults = {
         "regex": False,
         "target": gaupol.targets.CURRENT,
         },
-    "speech_recognition": {
-        "acoustic_model": "",
-        "advance_length": 100,
-        "lang_model": "",
-        "noise_level": 256,
-        "phonetic_dict": "",
-        "silence_length": 300,
-        "use_custom_models": False,
-        },
     "spell_check": {
         "field": gaupol.fields.MAIN_TEXT,
         "inline": False,
@@ -193,11 +184,11 @@ config_defaults = {
         "seek_length": 30.0,
         "subtitle_alpha": 1.0,
         "subtitle_background": True,
-        "subtitle_color": "#ffffff",
+        "subtitle_color": "#FFFFFF",
         "subtitle_font": "PT Sans Caption 18",
         "time_alpha": 1.0,
         "time_background": True,
-        "time_color": "#ffffff",
+        "time_color": "#FFFFFF",
         "time_font": "PT Mono Bold 14",
         "volume": None,
         },
@@ -261,10 +252,10 @@ class EnumDecoder(json.JSONDecoder):
 
     def __init__(self, *args, **kwargs):
         """
-        Initialize a :class:`EnumDecoder` object.
+        Initialize an :class:`EnumDecoder` instance.
 
-        `kwargs` should contain an "enum" key with a value of ``None`` if not
-        decoding an enumeration or the corresponding
+        `kwargs` should contain an "enum" key with a value of ``None``
+        if not decoding an enumeration or the corresponding
         :class:`aeidon.Enumeration` instance if decoding an enumeration.
         """
         self.enum = kwargs["enum"]
@@ -282,6 +273,20 @@ class EnumDecoder(json.JSONDecoder):
         return getattr(self.enum, string)
 
 
+class EnumEncoder(json.JSONEncoder):
+
+    """JSON encoder for enumerations of :mod:`aeidon` and :mod:`gaupol`."""
+
+    def encode(self, obj):
+        """Return JSON string matching `obj`."""
+        if isinstance(obj, aeidon.EnumerationItem):
+            return str(obj)
+        if isinstance(obj, (list, tuple)) and obj:
+            if isinstance(obj[0], aeidon.EnumerationItem):
+                return "[{}]".format(", ".join(map(str, obj)))
+        return json.JSONEncoder.encode(self, obj)
+
+
 class ConfigurationStore(gaupol.AttributeDictionary):
 
     """
@@ -296,34 +301,16 @@ class ConfigurationStore(gaupol.AttributeDictionary):
     _enums = config_enums
 
     def __init__(self):
-        """Initialize a :class:`ConfigurationStore` object."""
-        root = aeidon.util.copy_dict(self._defaults)
+        """Initialize a :class:`ConfigurationStore` instance."""
+        root = copy.deepcopy(self._defaults)
         gaupol.AttributeDictionary.__init__(self, root)
         self.path = None
 
-    def _flatten(self, values):
-        """Return a flattened version of `values` dictionary."""
-        def flatten(deep, parent):
-            flat_dict = {parent: {}}
-            deep = aeidon.util.copy_dict(deep)
-            for key, value in deep.items():
-                if isinstance(value, dict):
-                    key = "::".join((parent, key))
-                    value = flatten(value, key)
-                    flat_dict.update(value)
-                else: # Non-dictionary key.
-                    flat_dict[parent][key] = value
-            if not flat_dict[parent]:
-                del flat_dict[parent]
-            return flat_dict
-        final_dict = {}
-        values = aeidon.util.copy_dict(values)
-        for key, value in values.items():
-            if isinstance(value, dict):
-                final_dict.update(flatten(value, key))
-            else: # Non-dictionary key.
-                final_dict[key] = value
-        return final_dict
+    def __setattr__(self, name, value):
+        """Avoid accidentally setting a tuple."""
+        if isinstance(value, tuple):
+            value = list(value)
+        return gaupol.AttributeDictionary.__setattr__(self, name, value)
 
     def connect_notify(self, sections, option, obj, *args):
         """Connect `option`'s notify signal to `obj`'s callback method."""
@@ -357,11 +344,35 @@ class ConfigurationStore(gaupol.AttributeDictionary):
         method = getattr(obj, method_name)
         container.disconnect(signal, method)
 
+    def _flatten(self, values):
+        """Return a flattened version of `values` dictionary."""
+        def flatten(deep, parent):
+            flat_dict = {parent: {}}
+            deep = copy.deepcopy(deep)
+            for key, value in deep.items():
+                if isinstance(value, dict):
+                    key = "::".join((parent, key))
+                    value = flatten(value, key)
+                    flat_dict.update(value)
+                else: # Non-dictionary key.
+                    flat_dict[parent][key] = value
+            if not flat_dict[parent]:
+                del flat_dict[parent]
+            return flat_dict
+        final_dict = {}
+        values = copy.deepcopy(values)
+        for key, value in values.items():
+            if isinstance(value, dict):
+                final_dict.update(flatten(value, key))
+            else: # Non-dictionary key.
+                final_dict[key] = value
+        return final_dict
+
     def query_default(self, sections, option):
         """
         Return default value of configuration option.
 
-        Raise :exc:`KeyError` if section or option not found.
+        Raise :exc:`LookupError` if section or option not found.
         """
         if isinstance(sections, str):
             sections = (sections,)
@@ -385,8 +396,7 @@ class ConfigurationStore(gaupol.AttributeDictionary):
             # Ignore all decoding errors, since all keys and all standard
             # values are all ASCII. This will only mangle recent etc.
             # filenames, which are always checked for existance anyway.
-            lines = open(self.path,
-                         "r",
+            lines = open(self.path, "r",
                          encoding=encoding,
                          errors="ignore").readlines()
 
@@ -413,15 +423,12 @@ class ConfigurationStore(gaupol.AttributeDictionary):
                 option = option.strip()
                 value = value.strip()
                 enum = enums.get(option, None)
-                try: value = json.loads(value, cls=EnumDecoder, enum=enum)
+                try:
+                    value = json.loads(value, cls=EnumDecoder, enum=enum)
                 except (AttributeError, ValueError):
                     print(("Failed to parse value '{}' of option '{}.{}' "
                            "from configuration file '{}'."
-                           .format(value,
-                                   "::".join(sections),
-                                   option,
-                                   self.path)),
-
+                           .format(value, "::".join(sections), option, self.path)),
                           file=sys.stderr)
 
                     continue
@@ -432,11 +439,7 @@ class ConfigurationStore(gaupol.AttributeDictionary):
                     # By discarding them here, we ensure a clean start.
                     print ("Discarding value '{}' of option '{}.{}' "
                            "from configuration file '{}'."
-                           .format(value,
-                                   "::".join(sections),
-                                   option,
-                                   self.path),
-
+                           .format(value, "::".join(sections), option, self.path),
                            file=sys.stderr)
 
                     continue
@@ -454,14 +457,14 @@ class ConfigurationStore(gaupol.AttributeDictionary):
         """
         Add section and options for extension.
 
-        `name` should be preferrably the module name of the extension and it
-        will appear in the section name as ``extensions::name``. `defaults`
+        `name` should be preferrably the module name of the extension and
+        it will appear in the section name as ``extensions::name``. `defaults`
         should be a dictionary of default values for options. `enums` should be
-        a dictionary of :class:`aeidon.Enumeration` instances corresponding to
-        enumeration items that appear in options.
+        a dictionary of :class:`aeidon.Enumeration` instances corresponding
+        to enumeration items that appear in options.
         """
         self._defaults["extensions"].update({name: defaults})
-        self.extensions.extend({name: aeidon.util.copy_dict(defaults)})
+        self.extensions.extend({name: copy.deepcopy(defaults)})
         self._enums["extensions"].update({name: enums or {}})
 
     def restore_defaults(self):
@@ -479,38 +482,37 @@ class ConfigurationStore(gaupol.AttributeDictionary):
         if self.path is None: return
         self.general.version = gaupol.__version__
         if not os.path.isdir(os.path.dirname(self.path)):
-            try: aeidon.util.makedirs(os.path.dirname(self.path))
+            try:
+                aeidon.util.makedirs(os.path.dirname(self.path))
             except (IOError, OSError):
                 aeidon.util.print_write_io(sys.exc_info(), self.path)
                 raise # IOError, OSError
         encoding = aeidon.util.get_default_encoding()
-        try: fobj = open(self.path, "w", encoding=encoding)
+        try:
+            f = open(self.path, "w", encoding=encoding)
         except (IOError, OSError):
             aeidon.util.print_write_io(sys.exc_info(), self.path)
             raise # IOError, OSError
         root = self._flatten(self._root)
         defaults = self._flatten(self._defaults)
         for section in sorted(root):
-            fobj.write(os.linesep)
-            fobj.write("[{}]".format(section))
-            fobj.write(os.linesep)
+            f.write("\n[{}]\n".format(section))
             for option in sorted(root[section]):
                 value = root[section][option]
-                json_value = json.dumps(value, ensure_ascii=False)
+                json_value = json.dumps(value, cls=EnumEncoder, ensure_ascii=False)
                 if (not section.startswith("extensions::") and
                     (not section in defaults or
                      not option in defaults[section])):
                     # Discard removed options, but always keep
                     # all options of all extensions.
                     continue
-                if (section in defaults) and (option in defaults[section]):
+                if section in defaults and option in defaults[section]:
                     if value == defaults[section][option]:
-                        fobj.write("# ")
-                try: fobj.write("{} = {}".format(option, json_value))
+                        f.write("# ")
+                try:
+                    f.write("{} = {}\n".format(option, json_value))
                 except UnicodeError:
                     print(("Failed to write value '{}' of option '{}.{}' "
                            "to configuration file '{}'."
                            .format(value, section, option, self.path)),
                           file=sys.stderr)
-
-                fobj.write(os.linesep)
