@@ -1,20 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2005-2008,2010,2012-2013 Osmo Salomaa
+# Copyright (C) 2005 Osmo Salomaa
 #
-# This file is part of Gaupol.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
-# Gaupol is free software: you can redistribute it and/or modify it under the
-# terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
 #
-# Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# Gaupol. If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Dialog for editing preferences."""
 
@@ -42,7 +41,7 @@ class EditorPage(aeidon.Delegate, gaupol.BuilderDialog):
                 "editor_spell_check_check",)
 
     def __init__(self, master, application):
-        """Initialize an :class:`EditorPage` object."""
+        """Initialize an :class:`EditorPage` instance."""
         aeidon.Delegate.__init__(self, master)
         self._set_attributes(self._widgets, "editor_")
         self.application = application
@@ -80,11 +79,11 @@ class EditorPage(aeidon.Delegate, gaupol.BuilderDialog):
         self._length_cell_check.set_active(show_cell)
         self._length_edit_check.set_active(show_edit)
         self._length_combo.set_active(gaupol.conf.editor.length_unit)
-        if gaupol.util.gtkspellcheck_available():
+        if gaupol.util.gtkspell_available():
             inline = gaupol.conf.spell_check.inline
             self._spell_check_check.set_active(inline)
             self._spell_check_check.set_sensitive(True)
-        else: # gtkspellcheck not available
+        else: # GtkSpell not available
             self._spell_check_check.set_active(False)
             self._spell_check_check.set_sensitive(False)
 
@@ -134,7 +133,7 @@ class ExtensionPage(aeidon.Delegate, gaupol.BuilderDialog):
                 "extensions_tree_view")
 
     def __init__(self, master, application):
-        """Initialize an :class:`ExtensionPage` object."""
+        """Initialize an :class:`ExtensionPage` instance."""
         aeidon.Delegate.__init__(self, master)
         self._set_attributes(self._widgets, "extensions_")
         self.application = application
@@ -235,17 +234,18 @@ class ExtensionPage(aeidon.Delegate, gaupol.BuilderDialog):
         store = self._tree_view.get_model()
         module = store[path][0]
         active = store[path][1]
-        if active: # Deactivating extension.
-            try: self.manager.teardown_extension(module)
+        if active:
+            try:
+                self.manager.teardown_extension(module)
+                gaupol.conf.extensions.active.remove(module)
             except gaupol.DependencyError:
                 title = _("Cannot deactivate extension")
                 message = _('Extension "{}" is required by other extensions.')
                 message = message.format(store[path][2])
                 dialog = gaupol.ErrorDialog(self._dialog, title, message)
                 dialog.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
+                dialog.set_default_response(Gtk.ResponseType.OK)
                 gaupol.util.flash_dialog(dialog)
-            else: # Deactivation successful.
-                gaupol.conf.extensions.active.remove(module)
         else: # Activating extension.
             self.manager.setup_extension(module)
             gaupol.conf.extensions.active.append(module)
@@ -269,9 +269,7 @@ class ExtensionPage(aeidon.Delegate, gaupol.BuilderDialog):
             self._preferences_button.set_sensitive(False)
 
 
-class FilePage(aeidon.Delegate,
-               gaupol.BuilderDialog,
-               metaclass=aeidon.Contractual):
+class FilePage(aeidon.Delegate, gaupol.BuilderDialog):
 
     """File preferences page."""
 
@@ -285,7 +283,7 @@ class FilePage(aeidon.Delegate,
                 "file_up_button")
 
     def __init__(self, master, application):
-        """Initialize a :class:`FilePage` object."""
+        """Initialize a :class:`FilePage` instance."""
         aeidon.Delegate.__init__(self, master)
         self._set_attributes(self._widgets, "file_")
         self.application = application
@@ -355,18 +353,10 @@ class FilePage(aeidon.Delegate,
         store = self._tree_view.get_model()
         self._tree_view.set_cursor(len(store) - 1)
 
-    def _on_auto_check_toggled_require(self, check_button):
-        assert aeidon.util.chardet_available()
-
     def _on_auto_check_toggled(self, check_button):
         """Save encoding auto-detection usage."""
         gaupol.conf.encoding.try_auto = check_button.get_active()
 
-    def _on_down_button_clicked_require(self, *args):
-        row = self._get_selected_row()
-        store = self._tree_view.get_model()
-        assert row < len(store) - 1
-
     def _on_down_button_clicked(self, *args):
         """Move the selected fallback encoding down."""
         row = self._get_selected_row()
@@ -380,9 +370,6 @@ class FilePage(aeidon.Delegate,
         """Save locale encoding usage."""
         gaupol.conf.encoding.try_locale = check_button.get_active()
 
-    def _on_remove_button_clicked_require(self, *args):
-        self._get_selected_row() is not None
-
     def _on_remove_button_clicked(self, *args):
         """Remove the selected fallback encoding."""
         row = self._get_selected_row()
@@ -393,9 +380,6 @@ class FilePage(aeidon.Delegate,
         if len(store) <= 0: return
         self._tree_view.set_cursor(max(row-1, 0))
 
-    def _on_up_button_clicked_require(self, *args):
-        self._get_selected_row() > 0
-
     def _on_up_button_clicked(self, *args):
         """Move the selected fallback encoding up."""
         row = self._get_selected_row()
@@ -433,7 +417,7 @@ class PreviewPage(aeidon.Delegate, gaupol.BuilderDialog):
                 "preview_offset_spin")
 
     def __init__(self, master, application):
-        """Initialize a :class:`PreviewPage` object."""
+        """Initialize a :class:`PreviewPage` instance."""
         aeidon.Delegate.__init__(self, master)
         self._set_attributes(self._widgets, "preview_")
         self.application = application
@@ -505,7 +489,7 @@ class VideoPage(aeidon.Delegate, gaupol.BuilderDialog):
                 "video_time_font_button")
 
     def __init__(self, master, application):
-        """Initialize a :class:`PreviewPage` object."""
+        """Initialize a :class:`PreviewPage` instance."""
         aeidon.Delegate.__init__(self, master)
         self._set_attributes(self._widgets, "video_")
         self.application = application
@@ -575,7 +559,7 @@ class PreferencesDialog(gaupol.BuilderDialog):
     _widgets = ("notebook",)
 
     def __init__(self, parent, application):
-        """Initialize a :class:`PreferencesDialog` object."""
+        """Initialize a :class:`PreferencesDialog` instance."""
         gaupol.BuilderDialog.__init__(self,
                                       "preferences-dialog.ui",
                                       connect_signals=False)
@@ -601,7 +585,7 @@ class PreferencesDialog(gaupol.BuilderDialog):
                      self._preview_page,
                      self._video_page):
 
-            for name in [x for x in dir(page) if x.startswith("_on_")]:
+            for name in (x for x in dir(page) if x.startswith("_on_")):
                 callbacks[name] = getattr(page, name)
         return callbacks
 
