@@ -1,20 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2006-2008,2010,2012 Osmo Salomaa
+# Copyright (C) 2006 Osmo Salomaa
 #
-# This file is part of Gaupol.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
-# Gaupol is free software: you can redistribute it and/or modify it under the
-# terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
 #
-# Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# Gaupol. If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Dialog for searching for and replacing text."""
 
@@ -42,7 +41,7 @@ def page_changing(function):
     return wrapper
 
 
-class SearchDialog(gaupol.BuilderDialog, metaclass=aeidon.Contractual):
+class SearchDialog(gaupol.BuilderDialog):
 
     """
     Dialog for searching for and replacing text.
@@ -52,10 +51,10 @@ class SearchDialog(gaupol.BuilderDialog, metaclass=aeidon.Contractual):
     :ivar _match_page: :class:`gaupol.Page` instance of the last match
     :ivar _match_row: Row in :attr:`_match_page` of the last match
     :ivar _match_span: Start, end position of the last match
-    :ivar _statuslabel: Instance of :class:`gaupol.FloatingLabel` used
-    :ivar _was_next: ``True`` if the last search was "next", else ``False``
     :ivar patterns: List of patterns previously searched for
     :ivar replacements: List of replacements previously used
+    :ivar _statuslabel: Instance of :class:`gaupol.FloatingLabel` used
+    :ivar _was_next: ``True`` if the last search was "next", else ``False``
     """
 
     _widgets = ("all_radio",
@@ -75,20 +74,20 @@ class SearchDialog(gaupol.BuilderDialog, metaclass=aeidon.Contractual):
                 "tran_check")
 
     def __init__(self, application):
-        """Initialize a :class:`SearchDialog` object."""
+        """Initialize a :class:`SearchDialog` instance."""
         gaupol.BuilderDialog.__init__(self, "search-dialog.ui")
+        self.application = application
         self._handle_page_changes = True
         self._match_doc = None
         self._match_page = None
         self._match_row = None
         self._match_span = None
         self._pattern_entry = self._pattern_combo.get_child()
+        self.patterns = []
         self._replacement_entry = self._replacement_combo.get_child()
+        self.replacements = []
         self._statuslabel = gaupol.FloatingLabel()
         self._was_next = None
-        self.application = application
-        self.patterns = []
-        self.replacements = []
         self._read_history("patterns")
         self._read_history("replacements")
         self._init_text_view()
@@ -171,7 +170,7 @@ class SearchDialog(gaupol.BuilderDialog, metaclass=aeidon.Contractual):
         docs = list(map(gaupol.util.text_field_to_document,
                         gaupol.conf.search.fields))
 
-        if (doc is None) or (not doc in docs):
+        if doc is None or not doc in docs:
             doc = (docs[0] if next else docs[-1])
         pos = self._get_cursor_offset(page, row, doc, next)
         return row, doc, pos
@@ -251,18 +250,44 @@ class SearchDialog(gaupol.BuilderDialog, metaclass=aeidon.Contractual):
         self._current_radio.set_active(target == gaupol.targets.CURRENT)
         self._update_search_targets()
 
+    @aeidon.deco.silent(gaupol.Default)
+    def next(self):
+        """Find the next match of pattern."""
+        page = self.application.get_current_page()
+        row, doc, pos = self._get_position(next=True)
+        pages = self.application.pages[:]
+        i = pages.index(page)
+        # Loop twice over the current page,
+        # since starting in the middle.
+        for page in (pages[i:] + pages[:i+1]):
+            self._set_pattern(page)
+            try:
+                # Return match in page after position.
+                row, doc, span = page.project.find_next(row, doc, pos)
+                return self._set_success_state(page, row, doc, span, next=True)
+            except StopIteration:
+                target = gaupol.conf.search.target
+                if target == gaupol.targets.CURRENT:
+                    # Fail wrapped single-page search.
+                    return self._set_failure_state()
+                # Proceed to the next page.
+                row = doc = pos = None
+        # Fail wrapped search of all pages.
+        self._set_failure_state()
+
     def _on_all_radio_toggled(self, radio_button):
         """Save search target."""
         gaupol.conf.search.target = self._get_target()
 
     def _on_application_page_changed(self, application, page):
         """Invalidate the current search if underlying data has changed."""
-        # If data in page was changed from outside the search dialog, the
-        # current search must be invalidated to avoid making edits (especially
-        # via the text view's focus-out handler) based on data that no longer
-        # exists. All search dialog's data changing methods should be wrapped
-        # to disable this handling of application's page-changed signals.
-        if self._handle_page_changes and (self._match_page is not None):
+        # If data in page was changed from outside the search dialog,
+        # the current search must be invalidated to avoid making edits
+        # (especially via the text view's focus-out handler) based on data
+        # that no longer exists. All search dialog's data changing methods
+        # need to be wrapped to disable this handling of application's
+        # page-changed signals.
+        if self._handle_page_changes and self._match_page is not None:
             self._reset_properties()
 
     def _on_current_radio_toggled(self, radio_button):
@@ -279,7 +304,7 @@ class SearchDialog(gaupol.BuilderDialog, metaclass=aeidon.Contractual):
 
     def _on_main_check_toggled(self, check_button):
         """Save search target."""
-        gaupol.conf.search.fields = self._get_fields()
+        gaupol.conf.search.fields = list(self._get_fields())
         self._search_vbox.set_sensitive(bool(self._get_fields()))
 
     def _on_next_button_clicked(self, *args):
@@ -353,9 +378,34 @@ class SearchDialog(gaupol.BuilderDialog, metaclass=aeidon.Contractual):
 
     def _on_tran_check_toggled(self, check_button):
         """Save search target."""
-        gaupol.conf.search.fields = self._get_fields()
+        gaupol.conf.search.fields = list(self._get_fields())
         self._search_vbox.set_sensitive(bool(self._get_fields()))
 
+    @aeidon.deco.silent(gaupol.Default)
+    def previous(self):
+        """Find the previous match of pattern."""
+        page = self.application.get_current_page()
+        row, doc, pos = self._get_position(next=False)
+        pages = self.application.pages[::-1]
+        i = pages.index(page)
+        # Loop twice over the current page,
+        # since starting in the middle.
+        for page in (pages[i:] + pages[:i+1]):
+            self._set_pattern(page)
+            try:
+                # Return match in page before position.
+                row, doc, span = page.project.find_previous(row, doc, pos)
+                return self._set_success_state(page, row, doc, span, next=False)
+            except StopIteration:
+                target = gaupol.conf.search.target
+                if target == gaupol.targets.CURRENT:
+                    # Fail wrapped single-page search.
+                    return self._set_failure_state()
+                # Proceed to the previous page.
+                row = doc = pos = None
+        # Fail wrapped search of all pages.
+        self._set_failure_state()
+
     def _read_history(self, name):
         """Read history from file of type `name`."""
         directory = os.path.join(aeidon.CONFIG_HOME_DIR, "search")
@@ -364,6 +414,45 @@ class SearchDialog(gaupol.BuilderDialog, metaclass=aeidon.Contractual):
         history = aeidon.util.readlines(path)
         setattr(self, name, history)
 
+    @page_changing
+    @aeidon.deco.silent(gaupol.Default)
+    def replace(self):
+        """Replace the current match of pattern."""
+        page = self.application.get_current_page()
+        if page is not self._match_page: return
+        self._set_replacement(page)
+        subtitle = page.project.subtitles[self._match_row]
+        length = len(subtitle.get_text(self._match_doc))
+        try:
+            page.project.replace()
+        except re.error as error:
+            return self._show_regex_error_dialog_replacement(str(error))
+        shift = (len(subtitle.get_text(self._match_doc)) - length)
+        self._match_span[1] += shift
+        if self._was_next:
+            return self.next()
+        return self.previous()
+
+    @page_changing
+    @aeidon.deco.silent(gaupol.Default)
+    def replace_all(self):
+        """Replace all matches of pattern."""
+        count = 0
+        target = gaupol.conf.search.target
+        for page in self.application.get_target_pages(target):
+            self._set_pattern(page)
+            self._set_replacement(page)
+            try:
+                count += page.project.replace_all()
+            except re.error as error:
+                self._show_regex_error_dialog_replacement(str(error))
+                break
+        self._reset_properties()
+        self._statuslabel.flash_text(aeidon.i18n.ngettext(
+                "Found and replaced {:d} occurence",
+                "Found and replaced {:d} occurences",
+                count).format(count))
+
     def _reset_properties(self):
         """Reset search properties to defaults."""
         self._match_page = None
@@ -395,9 +484,10 @@ class SearchDialog(gaupol.BuilderDialog, metaclass=aeidon.Contractual):
         flags = re.DOTALL | re.MULTILINE
         if gaupol.conf.search.ignore_case:
             flags = flags | re.IGNORECASE
-        try: page.project.set_search_regex(pattern, flags)
-        except re.error as message:
-            self._show_regex_error_dialog_pattern(str(message))
+        try:
+            page.project.set_search_regex(pattern, flags)
+        except re.error as error:
+            self._show_regex_error_dialog_pattern(str(error))
             raise gaupol.Default
         self._add_pattern_to_history()
 
@@ -442,16 +532,18 @@ class SearchDialog(gaupol.BuilderDialog, metaclass=aeidon.Contractual):
 
     def _show_regex_error_dialog_pattern(self, message):
         """Show an error dialog if regex pattern failed to compile."""
-        title = _('Error in regular expression pattern')
+        title = _("Error in regular expression pattern")
         dialog = gaupol.ErrorDialog(self._dialog, title, message)
         dialog.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
+        dialog.set_default_response(Gtk.ResponseType.OK)
         gaupol.util.flash_dialog(dialog)
 
     def _show_regex_error_dialog_replacement(self, message):
         """Show an error dialog if regex replacement is invalid."""
-        title = _('Error in regular expression replacement')
+        title = _("Error in regular expression replacement")
         dialog = gaupol.ErrorDialog(self._dialog, title, message)
         dialog.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
+        dialog.set_default_response(Gtk.ResponseType.OK)
         gaupol.util.flash_dialog(dialog)
 
     def _update_search_targets(self):
@@ -466,110 +558,9 @@ class SearchDialog(gaupol.BuilderDialog, metaclass=aeidon.Contractual):
     def _write_history(self, name):
         """Write history to file of type `name`."""
         directory = os.path.join(aeidon.CONFIG_HOME_DIR, "search")
-        try: aeidon.util.makedirs(directory)
-        except OSError: return
-        path = os.path.join(directory, "{}.history".format(name))
-        history = getattr(self, name)
-        text = os.linesep.join(history) + os.linesep
-        aeidon.util.write(path, text)
-
-    def next_require(self):
-        assert self._pattern_entry.get_text()
-
-    @aeidon.deco.silent(gaupol.Default)
-    def next(self):
-        """Find the next match of pattern."""
-        page = self.application.get_current_page()
-        row, doc, pos = self._get_position(True)
-        pages = self.application.pages[:]
-        i = pages.index(page)
-        # Loop twice over the current page,
-        # since starting in the middle.
-        for page in (pages[i:] + pages[:i + 1]):
-            self._set_pattern(page)
-            try:
-                # Return match in page after position.
-                row, doc, span = page.project.find_next(row, doc, pos)
-                return self._set_success_state(page, row, doc, span, True)
-            except StopIteration:
-                target = gaupol.conf.search.target
-                if target == gaupol.targets.CURRENT:
-                    # Fail wrapped single-page search.
-                    return self._set_failure_state()
-                # Proceed to the next page.
-                row = doc = pos = None
-        # Fail wrapped search of all pages.
-        self._set_failure_state()
-
-    def previous_require(self):
-        assert self._pattern_entry.get_text()
-
-    @aeidon.deco.silent(gaupol.Default)
-    def previous(self):
-        """Find the previous match of pattern."""
-        page = self.application.get_current_page()
-        row, doc, pos = self._get_position(False)
-        pages = self.application.pages[::-1]
-        i = pages.index(page)
-        # Loop twice over the current page,
-        # since starting in the middle.
-        for page in (pages[i:] + pages[:i + 1]):
-            self._set_pattern(page)
-            try:
-                # Return match in page before position.
-                row, doc, span = page.project.find_previous(row, doc, pos)
-                return self._set_success_state(page, row, doc, span, False)
-            except StopIteration:
-                target = gaupol.conf.search.target
-                if target == gaupol.targets.CURRENT:
-                    # Fail wrapped single-page search.
-                    return self._set_failure_state()
-                # Proceed to the previous page.
-                row = doc = pos = None
-        # Fail wrapped search of all pages.
-        self._set_failure_state()
-
-    def replace_require(self):
-        assert self._match_doc  is not None
-        assert self._match_page is not None
-        assert self._match_row  is not None
-        assert self._match_span is not None
-        assert self._was_next   is not None
-
-    @page_changing
-    @aeidon.deco.silent(gaupol.Default)
-    def replace(self):
-        """Replace the current match of pattern."""
-        page = self.application.get_current_page()
-        if page is not self._match_page: return
-        self._set_replacement(page)
-        subtitle = page.project.subtitles[self._match_row]
-        length = len(subtitle.get_text(self._match_doc))
-        try: page.project.replace()
-        except re.error as message:
-            return self._show_regex_error_dialog_replacement(str(message))
-        shift = (len(subtitle.get_text(self._match_doc)) - length)
-        self._match_span[1] += shift
-        (self.next if self._was_next else self.previous)()
-
-    def replace_all_require(self):
-        assert self._pattern_entry.get_text()
-
-    @page_changing
-    @aeidon.deco.silent(gaupol.Default)
-    def replace_all(self):
-        """Replace all matches of pattern."""
-        count = 0
-        target = gaupol.conf.search.target
-        for page in self.application.get_target_pages(target):
-            self._set_pattern(page)
-            self._set_replacement(page)
-            try: count += page.project.replace_all()
-            except re.error as message:
-                self._show_regex_error_dialog_replacement(str(message))
-                break
-        self._reset_properties()
-        self._statuslabel.flash_text(aeidon.i18n.ngettext(
-                "Found and replaced {:d} occurence",
-                "Found and replaced {:d} occurences",
-                count).format(count))
+        with aeidon.util.silent(OSError):
+            aeidon.util.makedirs(directory)
+            path = os.path.join(directory, "{}.history".format(name))
+            history = getattr(self, name)
+            text = "\n".join(history) + "\n"
+            aeidon.util.write(path, text)
