@@ -2,19 +2,18 @@
 
 # Copyright (C) 2013 Osmo Salomaa
 #
-# This file is part of Gaupol.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
-# Gaupol is free software: you can redistribute it and/or modify it under the
-# terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
 #
-# Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# Gaupol. If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Floating label that can be overlaid on another widget."""
 
@@ -35,7 +34,7 @@ class FloatingLabel(Gtk.Box):
     # https://git.gnome.org/browse/nautilus/tree/src/nautilus-floating-bar.c
 
     def __init__(self):
-        """Initialize a :class:`FloatingLabel` object."""
+        """Initialize a :class:`FloatingLabel` instance."""
         GObject.GObject.__init__(self, orientation=Gtk.Orientation.HORIZONTAL)
         self._label = Gtk.Label()
         self._event_box = Gtk.EventBox()
@@ -45,41 +44,6 @@ class FloatingLabel(Gtk.Box):
         self.props.valign = Gtk.Align.END
         self._init_widgets()
 
-    def _get_label_background_color(self):
-        """Return a background color to use for the label."""
-        infobar = Gtk.InfoBar(message_type=Gtk.MessageType.INFO)
-        infobar.show()
-        style = infobar.get_style_context()
-        found, color = style.lookup_color("info_bg_color")
-        if found: return color
-        entry = Gtk.Entry()
-        entry.show()
-        style = entry.get_style_context()
-        return style.get_background_color(Gtk.StateFlags.NORMAL)
-
-    def _get_label_color(self):
-        """Return a foreground color to use for the label."""
-        infobar = Gtk.InfoBar(message_type=Gtk.MessageType.INFO)
-        infobar.show()
-        style = infobar.get_style_context()
-        found, color = style.lookup_color("info_fg_color")
-        if found: return color
-        entry = Gtk.Entry()
-        entry.show()
-        style = entry.get_style_context()
-        return style.get_color(Gtk.StateFlags.NORMAL)
-
-    def _init_widgets(self):
-        """Initialize widgets contained in the box."""
-        fg = self._get_label_color()
-        bg = self._get_label_background_color()
-        self._label.override_color(Gtk.StateFlags.NORMAL, fg)
-        self._label.override_background_color(Gtk.StateFlags.NORMAL, bg)
-        self._label.set_name("gaupol-floating-label")
-        self._event_box.add(self._label)
-        self.pack_start(self._event_box, expand=False, fill=False, padding=0)
-        self._event_box.connect("enter-notify-event", self.hide)
-
     def flash_text(self, text, duration=6):
         """Show label with `text` for `duration` seconds."""
         self.set_text(text)
@@ -97,6 +61,13 @@ class FloatingLabel(Gtk.Box):
             if widget.handler_is_connected(handler_id):
                 widget.handler_disconnect(handler_id)
 
+    def _init_widgets(self):
+        """Initialize widgets contained in the box."""
+        self._label.set_name("gaupol-floating-label")
+        self._event_box.add(self._label)
+        gaupol.util.pack_start(self, self._event_box)
+        self._event_box.connect("enter-notify-event", self.hide)
+
     def register_hide_event(self, widget, signal):
         """Register `widget`'s `signal` as cause to hide the label."""
         handler_id = widget.connect(signal, self.hide)
